@@ -24,18 +24,14 @@
 
 #include <glib.h>
 
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkrange.h>
-#include <gtk/gtkwindow.h>
-#include <gst/gst.h>
-#ifdef HAVE_GST10
-#include <gst/interfaces/mixer.h>
-#else
-#include <gst/mixer/mixer.h>
-#endif
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
+/* FIXME: This is necessary to avoid circular references in the headers.
+ * This can be fixed by breaking the applet object into a model and a view. */
+typedef struct _GnomeVolumeApplet GnomeVolumeApplet;
+
 #define GNOME_VOLUME_APPLET_TYPE_DOCK \
   (gnome_volume_applet_dock_get_type ())
 #define GNOME_VOLUME_APPLET_DOCK(obj) \
@@ -55,6 +51,7 @@ typedef struct _GnomeVolumeAppletDock {
   /* us */
   GtkRange *scale;
   GtkButton *plus, *minus;
+  GtkWidget *mute;
 
   /* timeout for buttons */
   guint timeout;
@@ -62,16 +59,20 @@ typedef struct _GnomeVolumeAppletDock {
 
   /* orientation */
   GtkOrientation orientation;
+
+  GnomeVolumeApplet *model;
 } GnomeVolumeAppletDock;
 
 typedef struct _GnomeVolumeAppletDockClass {
   GtkWindowClass klass;
 } GnomeVolumeAppletDockClass;
 
-GType		gnome_volume_applet_dock_get_type	(void);
-GtkWidget *	gnome_volume_applet_dock_new		(GtkOrientation orientation);
-void		gnome_volume_applet_dock_change		(GnomeVolumeAppletDock *dock,
-							 GtkAdjustment *adj);
+GType gnome_volume_applet_dock_get_type	(void);
+GtkWidget *gnome_volume_applet_dock_new (GtkOrientation orientation,
+					 GnomeVolumeApplet *parent);
+void gnome_volume_applet_dock_change (GnomeVolumeAppletDock *dock,
+				      GtkAdjustment *adj);
+void gnome_volume_applet_dock_set_focus (GnomeVolumeAppletDock *dock);
 
 G_END_DECLS
 
